@@ -1,10 +1,14 @@
 context("Download books")
 
+# These tests are currently skipped on CRAN, which has issues connecting
+# to Project Gutenberg. See test-mock for tests that are performed without
+# connecting to PG.
+
 library(stringr)
 suppressPackageStartupMessages(library(dplyr))
 
-
 test_that("gutenberg_get_mirror works", {
+  skip_on_cran()
   m <- gutenberg_get_mirror()
 
   expect_is(m, "character")
@@ -16,6 +20,7 @@ test_that("gutenberg_get_mirror works", {
 
 
 test_that("Can download Charles Dickens' Christmas Carol and Jane Austen's Persuasion", {
+  skip_on_cran()
   books <- gutenberg_download(c(46, 105), meta_fields = c("title", "author"))
 
   # should be at least a substantial amount of text in each
@@ -37,6 +42,7 @@ test_that("Can download Charles Dickens' Christmas Carol and Jane Austen's Persu
 
 
 test_that("Can download books from a data frame with gutenberg_id column", {
+  skip_on_cran()
   d <- gutenberg_works(title == "The United States Constitution") %>%
     gutenberg_download()
   expect_true(inherits(d, "data.frame"))
@@ -46,12 +52,14 @@ test_that("Can download books from a data frame with gutenberg_id column", {
 
 
 test_that("We can download a file that only has a -8 version", {
+  skip_on_cran()
   d <- gutenberg_download(8438)
   expect_gt(sum(str_detect(d$text, "Aristotle")), 50)
 })
 
 
 test_that("Trying to download a non-existent book raises a warning", {
+  skip_on_cran()
   expect_warning(d <- gutenberg_download(c(5, 1000000)), "Could not download")
   expect_true(inherits(d, "data.frame"))
   expect_true(all(d$gutenberg_id == 5))
